==> merchant-base-0.3-20230313.063541-314-sources.jar: com/rocogz/merchant/entity/scm/MerchantScmOrderDetail.java <==
package com.rocogz.merchant.entity.scm;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.rocogz.merchant.constant.Constant;
import com.rocogz.merchant.dto.scm.ScmSendDto;
import com.rocogz.merchant.entity.channel.product.MerchantChannelProduct;
import com.rocogz.merchant.entity.goods.MerchantGoods;
import com.rocogz.merchant.entity.goods.MerchantGoodsMeal;
import com.rocogz.merchant.entity.goods.MerchantGoodsValidityRule;
import com.rocogz.syy.common.entity.IdEntity;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;

import java.math.BigDecimal;
import java.time.LocalDate;
import java.time.LocalDateTime;

/**
 * <p>
 * 明细订单
 * </p>
 *
 * @author liangyongtong
 * @since 2021-03-09
 */
@Data
@EqualsAndHashCode(callSuper = true)
@Accessors(chain = true)
public class MerchantScmOrderDetail extends IdEntity {

    private static final long serialVersionUID = 4042786962586393961L;
    /**
     * 订单号
     */
    private String orderCode;

    /**
     * 二级订单分组编码
     */
    private String itemGroupCode;

    /**
     * 明细订单编号
     */
    private String orderItemCode;

    /**
     * 合作客户产品编码
     */
    private String customerProductCode;

    /**
     * 合作客户产品名称
     */
    private String customerProductName;

    /**
     * 代理商产品编码
     */
    private String agentProductCode;

    /**
     * 代理商产品名称
     */
    private String agentProductName;

    /**
     * 平台商品编码
     */
    private String productCode;

    /**
     * 平台商品名称
     */
    private String productName;


    /**
     * 产品类别
     *
     * @see Constant.DictData#PRODUCT_TYPE_DRIVING_SERVICE
     */
    private String productType;

    /**
     * 第三方产品编码,即上游产品编号,供应商产品编号
     * (1) 就是 在分销聚合服务项目-> 创建平台产品页面中 产品供应商信息中 填写的 供应商产品编号
     * (2) 同时也是 在分销聚合服务项目-> 创建通道产品页面中 填写的 第三方产品编号
     *
     * @see MerchantScmProductInformation#thirdProductCode
     * @see MerchantChannelProduct#thirdProductCode
     */
    private String thirdProductCode;

    /**
     * 上游订单重试次数
     */
    private Integer retryNum;

    /**
     * 上游订单最后重试时间
     */
    private LocalDateTime lastestRetryTime;

    /**
     * 回调地址
     */
    private String callbackUrl;

    /**
     * 上游订单订单状态:调用dingju后更新上游订单状态
     * 更新上游订单入口：在com.rocogz.syy.message.server.scm.MerchantScmOrderHandler实现类中回调更新
     * （1）com.rocogz.syy.message.server.scm.consumer.ScmConsumer#handleReorderJms
     * （2）com.rocogz.syy.message.server.scm.consumer.ScmConsumer#handleOrderJms
     *
     * @see Constant.DictData#SCM_ORDER_STATUS_PENDING
     */
    private String orderStatus;

    /**
     * 第三方业务状态
     */
    private String thirdBusinessStatus;

    /**
     * 第三方业务号,例如：鼎聚的powerNo
     */
    private String thirdBusinessCode;

    /**
     * 第三方失败原因
     */
    private String thirdReason;

    /**
     * 发放张数:下游订单张数 =1
     */
    private Integer grantNum;

    /**
     * ROCO车服用户券号
     */
    private String rocoUserCouponCode;

    /**
     * 用户券发放状态:
     * 待发放或已发放
     *
     * @see Constant.DictData#SCM_USER_COUPON_GRANT_STATUS_PENDING
     */
    private String userCouponGrantStatus;

    /**
     * 用户券发放异常原因
     */
    private String userCouponGrantErrorReason;

    /**
     * 用户券发放重试次数
     */
    private Integer userCouponGrantRetryNum;

    /**
     * 产品性质:单品/供应商定制套餐/平台定制套餐
     *
     * @see Constant.DictData#GOODS_NATURE_ITEM
     */
    private String goodsNature;

    /**
     * 订单核销状态,车主单核销后,权益基础服务发消息通知更新此核销状态
     */
    private String writeOffStatus;

    /**
     * 订单核销时间
     */
    private LocalDateTime writeOffTime;

    /**
     * 单个明细订单面值/平台产品市场价, 不管是积分兑换，还是发放的,壳牌的都是 非固定面额的
     *  调用上游 鼎聚的油卡充值金额 传入的就是这个字段  <br/>
     *  调用上游 电卡充值金额 传入的也是这个字段  <br/>
     *
     * （1）非固定面额的油卡直充:        detailPrice = 充值金额 拆单后的面额 {@link ScmSendDto#unitFaceValue}
     * （2）如果是非固定面额电卡或积分：  detailPrice = 输入的充值金额 {@link ScmSendDto#unitFaceValue}
     * （3）其他产品类型 ：            detailPrice = 平台产品市场价 {@link MerchantGoods#marketPrice}
     *  (4)如果是自定义平台套餐：      detailPrice =  {@link MerchantGoodsMeal#marketPrice}
     */
    private BigDecimal detailPrice;

    /**
     * 如果是C端加油的 discountAmt = {@link ScmSendDto#discountAmount} 拆单后的优惠抵扣金额
     */
    private BigDecimal discountAmt;

    /**
     * 本明细订单应该发放用户券张数，如果是套餐，则等于= sum(所有套餐子商品的com.rocogz.merchant.entity.goods.MerchantGoodsMeal#sum）
     * 如果是供应商套餐，itemGrantNum = 该orderItemCode下的所有merchant_scm_order_combo_detail
     * 如果是单品=1
     */
    private Integer itemGrantNum;

    /**
     * 本明细订单发放用户券成功张数
     */
    private Integer itemGrantSuccessNum;

    /**
     * 本明细订单用户券发放成功时间
     */
    private LocalDateTime itemGrantSuccessTime;

    /**
     * 第三方业务编号更新到权益中心状态
     */
    private String powerNoToEquityStatus;

    /**
     * 第三方业务编号更新到权益中心执行次数
     */
    private Integer powerNoToEquityNum;

    /**
     * 领取验证状态：用来标记：车主端客户是否点击了领取按钮
     */
    private String receiveValidateStatus;

    /**
     * 领取验证时间
     */
    private LocalDateTime receiveValidateTime;

    /**
     * 备付金扣减时点
     */
    private String dedutionTimePoint;

    /**
     * 备付金扣减状态：UNPAID、FAILURE、SUCCESS
     *
     * @see Constant.DictData#SCM_PAY_STATUS_FAILURE
     */
    private String coverPayStatus;

    /**
     * 备付金扣减成功时,备付金账户交易流水号
     */
    private String coverFlowCode;

    /**
     * 备付金扣减尝试次数
     */
    private Integer coverPayRetryNum;

    /**
     * 总备付金扣减金额
     */
    private BigDecimal coverPayPrice;

    /**
     * 备付金尝试扣减时间
     */
    private LocalDateTime coverPayTime;

    /**
     * 备付金领取状态：备付金账户中的领取金额是否增加成功
     */
    private String coverReceiveStatus;

    /**
     * 备付金退款状态
     */
    private String refundStatus;

    /**
     * 备付金退款金额 = payQuotaPrice
     */
    private BigDecimal refundPrice;

    /**
     * 备付金退款时间
     */
    private LocalDateTime refundTime;

    /**
     * 撤回时间
     */
    private LocalDateTime recallTime;

    /**
     * 订单类型
     *
     * @see Constant.DictData#SCM_ORDER_TYPE_SYS
     */
    private String orderType;

    /**
     * 备付金支付金额,备付金账号需要扣减的备付金金额
     */
    private BigDecimal payQuotaPrice;

    /**
     * 现金支付金额
     */
    private BigDecimal payCashPrice;

    /**
     * 上游订单发放成功时间
     */
    private LocalDateTime thirdGrantSuccessTime;


    /**
     * 平台产品采购单价
     *
     * @see MerchantGoodsMeal#costPrice (平台自定义套餐)
     * @see MerchantGoods#costPrice
     */
    private BigDecimal platProdPurchasePrice;

    /**
     * 平台产品 市场单价/面额
     */
    private BigDecimal platProdMarketPrice;


    /**
     * 调用上游接口 触发方式：自动/手工
     *
     * @see Constant.DictTriggerRemoteApiMode#MANUAL
     * @see MerchantGoodsValidityRule#remoteTriggerMode
     */
    private String triggerRemoteApiMode;

    /**
     * 使用有效期设置时点：发放时设置，领取时设置
     *
     * @see Constant.DictValiditySettingTimePoint#ISSUE
     * @see MerchantGoodsValidityRule#settingTimePoint
     */
    private String useValiditySetTimePoint;

    /**
     * 使用有效期规则Json
     *
     * @see MerchantGoodsValidityRule
     */
    private String useValidityRuleJson;

    /**
     * 平台产品延迟多少天失效【失效类型是 延迟生效】
     *
     * @see MerchantGoods#useValidity
     */
    private Integer useValidityInvalidDelayDays;

    /**
     * 使用有效期：开始日期
     */
    private LocalDate useValidityStartDate;

    /**
     * 使用有效期：结束日期
     */
    private LocalDate useValidityEndDate;

    /**
     * 使用有效期状态：未生效，已生效，已过期
     *
     * @see Constant.DictValidityStatus#INEFFECTIVE
     */
    private String useValidityStatus;

    /**
     * 已过期标志位：只要领取有效期或使用有效期过期了，就算过期
     */
    private Integer expireFlag;

    /**
     * 使用状态：未使用，部分使用、已使用（只有油卡,积分类型的，并且使用有效期过期后才会更新此字段）
     * 现在的业务：只是使用有效期过期后,调用interface查询油卡余额接口更新此字段
     * @see Constant.DictUseStatus
     */
    private String useStatus;

    /**
     * 使用状态更新时间
     */
    private LocalDateTime useUpdateTime;

    /**
     * 过期处理状态
     *
     * @see Constant.DictValidityExpiredHandleStatus
     */
    private String expiredHandleStatus;

    /**
     * 通道产品-编码
     *
     * @see MerchantChannelProduct#code
     */
    private String channelProductCode;

    /**
     * 通道产品-名称
     */
    private String channelProductName;

    /**
     * 通道产品-第三方平台编码
     *
     * @see MerchantChannelProduct#platformCode
     */
    private String channelProductPlatformCode;

    /**
     * 通道产品-第三方平台名称
     */
    private String channelProductPlatformName;

    /**
     * 通道产品-扣款主体编号
     *
     * @see MerchantChannelProduct#deductSubjectCode
     */
    private String channelProductDeductSubjectCode;

    /**
     * 通道产品-扣款主体名称
     */
    private String channelProductDeductSubjectName;

    /**
     * 通道产品-成本价
     */
    private BigDecimal channelProductPurchasePrice;

    /**
     * 通道产品-市场价
     */
    private BigDecimal channelProductMarketPrice;

    /**
     * 通道产品-过期操作类型
     *
     * @see MerchantChannelProduct#orderDelayReissue
     */
    private String channelProductOrderDelayReissue;

    /**
     * 第三方订单号
     */
    private String thirdOrderCode;


    /**
     * 发放的实物供应链订单(非积分兑换的),对应的商品订单创建状态
     *
     * @see Constant.DictData#SCM_GOODS_ORDER_CREATE_RESULT_PENDING
     * 实物订单创建结果
     */
    private String goodsOrderCreateResult;

    /**
     * 实物订单创建次数
     */
    private Integer goodsOrderCreateRetryNum;

    /**
     * 实物订单创建失败原因
     */
    private String goodsOrderCreateFailReason;

    /**
     * 实物订单创建时间
     */
    private LocalDateTime goodsOrderCreateTime;


    /**
     * 是否已完成补发 （Y/N）
     *
     * @see Constant.DictData#COMMON_STATUS_YES
     */
    private String reissued;

    /**
     * 过期订单对应的补发下游订单号【被补发订单有值】,例如：SCM20210312000010
     */
    private String reissueBy;

    /**
     * 补发订单对应的，为哪个上游订单补发[补发的订单有值]，例如：SCM20210705001641_1_1
     */
    private String reissueFor;

    /**
     * 补发金额 【被补发订单有值】
     */
    private BigDecimal reissuedAmount;

    /**
     * 过期金额
     */
    private BigDecimal expiredAmount;


    /**
     * 已延期次数，默认为0
     */
    private Integer deferCnt;


    //=== 下面的属性用来传值


    /**
     * 是否是电卡产品订单
     * @return
     */
    @JsonIgnore
    public boolean isElectricOrder() {
        return Constant.DictData.PRODUCT_TYPE_FIXED_ELECTRIC.equalsIgnoreCase(productType)
                ||  Constant.DictData.PRODUCT_TYPE_FLEXIBLE_ELECTRIC.equalsIgnoreCase(productType);
    }


    //产品订单发放平台信息
    private transient MerchantScmInformation scmGrantInfo;

    //产品订单 目标用户表
    private transient MerchantScmTargetUser scmGrantTargetUser;

    private transient MerchantScmProductInformation scmProductInfo;

    private transient MerchantScmOrderInformation orderInformation;

}

==> merchant-base-0.3-20230421.072125-321-sources.jar: com/rocogz/merchant/entity/scm/MerchantScmOrderDetail.java <==
package com.rocogz.merchant.entity.scm;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.rocogz.merchant.constant.Constant;
import com.rocogz.merchant.dto.scm.ScmSendDto;
import com.rocogz.merchant.entity.channel.product.MerchantChannelProduct;
import com.rocogz.merchant.entity.goods.MerchantGoods;
import com.rocogz.merchant.entity.goods.MerchantGoodsMeal;
import com.rocogz.merchant.entity.goods.MerchantGoodsValidityRule;
import com.rocogz.syy.common.entity.IdEntity;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;

import java.math.BigDecimal;
import java.time.LocalDate;
import java.time.LocalDateTime;

/**
 * <p>
 * 明细订单
 * </p>
 *
 * @author liangyongtong
 * @since 2021-03-09
 */
@Data
@EqualsAndHashCode(callSuper = true)
@Accessors(chain = true)
public class MerchantScmOrderDetail extends IdEntity {

    private static final long serialVersionUID = 4042786962586393961L;
    /**
     * 订单号，供应链下游订单号
     */
    private String orderCode;

    /**
     * 二级订单分组编码
     */
    private String itemGroupCode;

    /**
     * 明细订单编号,即供应链上游订单号
     * @see com.rocogz.syy.equity.entity.userCoupon.EquityUserCouponLaunchInfo#orderItemCode 发放用户券时设置到发放信息此字段上
     */
    private String orderItemCode;

    /**
     * 合作客户产品编码
     */
    private String customerProductCode;

    /**
     * 合作客户产品名称
     */
    private String customerProductName;

    /**
     * 代理商产品编码
     */
    private String agentProductCode;

    /**
     * 代理商产品名称
     */
    private String agentProductName;

    /**
     * 平台商品编码
     */
    private String productCode;

    /**
     * 平台商品名称
     */
    private String productName;


    /**
     * 产品类别
     *
     * @see Constant.DictData#PRODUCT_TYPE_DRIVING_SERVICE
     */
    private String productType;

    /**
     * 第三方产品编码,即上游产品编号,供应商产品编号
     * (1) 就是 在分销聚合服务项目-> 创建平台产品页面中 产品供应商信息中 填写的 供应商产品编号
     * (2) 同时也是 在分销聚合服务项目-> 创建通道产品页面中 填写的 第三方产品编号
     *
     * @see MerchantScmProductInformation#thirdProductCode
     * @see MerchantChannelProduct#thirdProductCode
     */
    private String thirdProductCode;

    /**
     * 上游订单重试次数
     */
    private Integer retryNum;

    /**
     * 上游订单最后重试时间
     */
    private LocalDateTime lastestRetryTime;

    /**
     * 回调地址
     */
    private String callbackUrl;

    /**
     * 上游订单订单状态:调用dingju后更新上游订单状态
     * 更新上游订单入口：在com.rocogz.syy.message.server.scm.MerchantScmOrderHandler实现类中回调更新
     * （1）com.rocogz.syy.message.server.scm.consumer.ScmConsumer#handleReorderJms
     * （2）com.rocogz.syy.message.server.scm.consumer.ScmConsumer#handleOrderJms
     *
     * @see Constant.DictData#SCM_ORDER_STATUS_PENDING
     */
    private String orderStatus;

    /**
     * 第三方业务状态
     */
    private String thirdBusinessStatus;

    /**
     * 第三方业务号,例如：鼎聚的powerNo
     */
    private String thirdBusinessCode;

    /**
     * 第三方失败原因
     */
    private String thirdReason;

    /**
     * 发放张数:下游订单张数 =1
     */
    private Integer grantNum;

    /**
     * ROCO车服用户券编号
     * @see com.rocogz.syy.equity.entity.userCoupon.EquityUserCouponInfo#code
     * @see com.rocogz.syy.equity.entity.userCoupon.EquityUserCouponLaunchInfo#userCouponCode
     */
    private String rocoUserCouponCode;

    /**
     * 用户券发放状态:
     * 待发放或已发放
     *
     * @see Constant.DictData#SCM_USER_COUPON_GRANT_STATUS_PENDING
     */
    private String userCouponGrantStatus;

    /**
     * 用户券发放异常原因
     */
    private String userCouponGrantErrorReason;

    /**
     * 用户券发放重试次数
     */
    private Integer userCouponGrantRetryNum;

    /**
     * 产品性质:单品/供应商定制套餐/平台定制套餐
     *
     * @see Constant.DictData#GOODS_NATURE_ITEM
     */
    private String goodsNature;

    /**
     * 订单核销状态,车主单核销后,权益基础服务发消息通知更新此核销状态
     */
    private String writeOffStatus;

    /**
     * 订单核销时间
     */
    private LocalDateTime writeOffTime;

    /**
     * 单个明细订单面值/平台产品市场价, 不管是积分兑换，还是发放的,壳牌的都是 非固定面额的
     *  调用上游 鼎聚的油卡充值金额 传入的就是这个字段  <br/>
     *  调用上游 电卡充值金额 传入的也是这个字段  <br/>
     *
     * （1）非固定面额的油卡直充:        detailPrice = 充值金额 拆单后的面额 {@link ScmSendDto#unitFaceValue}
     * （2）如果是非固定面额电卡或积分：  detailPrice = 输入的充值金额 {@link ScmSendDto#unitFaceValue}
     * （3）其他产品类型 ：            detailPrice = 平台产品市场价 {@link MerchantGoods#marketPrice}
     *  (4)如果是自定义平台套餐：      detailPrice =  {@link MerchantGoodsMeal#marketPrice}
     */
    private BigDecimal detailPrice;

    /**
     * 如果是C端加油的 discountAmt = {@link ScmSendDto#discountAmount} 拆单后的优惠抵扣金额
     */
    private BigDecimal discountAmt;

    /**
     * 本明细订单应该发放用户券张数，如果是套餐，则等于= sum(所有套餐子商品的com.rocogz.merchant.entity.goods.MerchantGoodsMeal#sum）
     * 如果是供应商套餐，itemGrantNum = 该orderItemCode下的所有merchant_scm_order_combo_detail
     * 如果是单品=1
     */
    private Integer itemGrantNum;

    /**
     * 本明细订单发放用户券成功张数
     */
    private Integer itemGrantSuccessNum;

    /**
     * 本明细订单用户券发放成功时间
     */
    private LocalDateTime itemGrantSuccessTime;

    /**
     * 第三方业务编号更新到权益中心状态
     */
    private String powerNoToEquityStatus;

    /**
     * 第三方业务编号更新到权益中心执行次数
     */
    private Integer powerNoToEquityNum;

    /**
     * 领取验证状态：用来标记：车主端客户是否点击了领取按钮
     */
    private String receiveValidateStatus;

    /**
     * 领取验证时间
     */
    private LocalDateTime receiveValidateTime;

    /**
     * 备付金扣减时点
     */
    private String dedutionTimePoint;

    /**
     * 备付金扣减状态：UNPAID、FAILURE、SUCCESS
     *
     * @see Constant.DictData#SCM_PAY_STATUS_FAILURE
     */
    private String coverPayStatus;

    /**
     * 备付金扣减成功时,备付金账户交易流水号
     */
    private String coverFlowCode;

    /**
     * 备付金扣减尝试次数
     */
    private Integer coverPayRetryNum;

    /**
     * 总备付金扣减金额
     */
    private BigDecimal coverPayPrice;

    /**
     * 备付金尝试扣减时间
     */
    private LocalDateTime coverPayTime;

    /**
     * 备付金领取状态：备付金账户中的领取金额是否增加成功
     */
    private String coverReceiveStatus;

    /**
     * 备付金退款状态
     */
    private String refundStatus;

    /**
     * 备付金退款金额 = payQuotaPrice
     */
    private BigDecimal refundPrice;

    /**
     * 备付金退款时间
     */
    private LocalDateTime refundTime;

    /**
     * 撤回时间
     */
    private LocalDateTime recallTime;

    /**
     * 订单类型
     *
     * @see Constant.DictData#SCM_ORDER_TYPE_SYS
     */
    private String orderType;

    /**
     * 备付金支付金额,备付金账号需要扣减的备付金金额
     */
    private BigDecimal payQuotaPrice;

    /**
     * 现金支付金额
     */
    private BigDecimal payCashPrice;

    /**
     * 上游订单发放成功时间
     */
    private LocalDateTime thirdGrantSuccessTime;


    /**
     * 平台产品采购单价
     *
     * @see MerchantGoodsMeal#costPrice (平台自定义套餐)
     * @see MerchantGoods#costPrice
     */
    private BigDecimal platProdPurchasePrice;

    /**
     * 平台产品 市场单价/面额
     */
    private BigDecimal platProdMarketPrice;


    /**
     * 调用上游接口 触发方式：自动/手工
     *
     * @see Constant.DictTriggerRemoteApiMode#MANUAL
     * @see MerchantGoodsValidityRule#remoteTriggerMode
     */
    private String triggerRemoteApiMode;

    /**
     * 使用有效期设置时点：发放时设置，领取时设置
     *
     * @see Constant.DictValiditySettingTimePoint#ISSUE
     * @see MerchantGoodsValidityRule#settingTimePoint
     */
    private String useValiditySetTimePoint;

    /**
     * 使用有效期规则Json
     *
     * @see MerchantGoodsValidityRule
     */
    private String useValidityRuleJson;

    /**
     * 平台产品延迟多少天失效【失效类型是 延迟生效】
     *
     * @see MerchantGoods#useValidity
     */
    private Integer useValidityInvalidDelayDays;

    /**
     * 使用有效期：开始日期
     */
    private LocalDate useValidityStartDate;

    /**
     * 使用有效期：结束日期
     */
    private LocalDate useValidityEndDate;

    /**
     * 使用有效期状态：未生效，已生效，已过期
     *
     * @see Constant.DictValidityStatus#INEFFECTIVE
     */
    private String useValidityStatus;

    /**
     * 已过期标志位：只要领取有效期或使用有效期过期了，就算过期
     */
    private Integer expireFlag;

    /**
     * 使用状态：未使用，部分使用、已使用（只有油卡,积分类型的，并且使用有效期过期后才会更新此字段）
     * 现在的业务：只是使用有效期过期后,调用interface查询油卡余额接口更新此字段
     * @see Constant.DictUseStatus
     */
    private String useStatus;

    /**
     * 使用状态更新时间
     */
    private LocalDateTime useUpdateTime;

    /**
     * 过期处理状态
     *
     * @see Constant.DictValidityExpiredHandleStatus
     */
    private String expiredHandleStatus;

    /**
     * 通道产品-编码
     *
     * @see MerchantChannelProduct#code
     */
    private String channelProductCode;

    /**
     * 通道产品-名称
     */
    private String channelProductName;

    /**
     * 通道产品-第三方平台编码
     *
     * @see MerchantChannelProduct#platformCode
     */
    private String channelProductPlatformCode;

    /**
     * 通道产品-第三方平台名称
     */
    private String channelProductPlatformName;

    /**
     * 通道产品-扣款主体编号
     *
     * @see MerchantChannelProduct#deductSubjectCode
     */
    private String channelProductDeductSubjectCode;

    /**
     * 通道产品-扣款主体名称
     */
    private String channelProductDeductSubjectName;

    /**
     * 通道产品-成本价
     */
    private BigDecimal channelProductPurchasePrice;

    /**
     * 通道产品-市场价
     */
    private BigDecimal channelProductMarketPrice;

    /**
     * 通道产品-过期操作类型
     *
     * @see MerchantChannelProduct#orderDelayReissue
     */
    private String channelProductOrderDelayReissue;

    /**
     * 第三方订单号
     */
    private String thirdOrderCode;


    /**
     * 发放的实物供应链订单(非积分兑换的),对应的商品订单创建状态
     *
     * @see Constant.DictData#SCM_GOODS_ORDER_CREATE_RESULT_PENDING
     * 实物订单创建结果
     */
    private String goodsOrderCreateResult;

    /**
     * 实物订单创建次数
     */
    private Integer goodsOrderCreateRetryNum;

    /**
     * 实物订单创建失败原因
     */
    private String goodsOrderCreateFailReason;

    /**
     * 实物订单创建时间
     */
    private LocalDateTime goodsOrderCreateTime;


    /**
     * 是否已完成补发 （Y/N）
     *
     * @see Constant.DictData#COMMON_STATUS_YES
     */
    private String reissued;

    /**
     * 过期订单对应的补发下游订单号【被补发订单有值】,例如：SCM20210312000010
     * 该值保存的新下游补发订单号，该字段的值保存在原过期上游订单记录上
     */
    private String reissueBy;

    /**
     * 补发订单对应的原上游订单号，为哪个上游订单补发[新补发的订单有值]，例如：SCM20210705001641_1_1
     * 保存的值是原上游订单号,该值记录在新补发上游订单上
     */
    private String reissueFor;

    /**
     * 补发金额 【被补发订单有值】
     */
    private BigDecimal reissuedAmount;

    /**
     * 过期金额
     */
    private BigDecimal expiredAmount;


    /**
     * 已延期次数，默认为0
     */
    private Integer deferCnt;


    //=== 下面的属性用来传值


    /**
     * 是否是电卡产品订单
     * @return
     */
    @JsonIgnore
    public boolean isElectricOrder() {
        return Constant.DictData.PRODUCT_TYPE_FIXED_ELECTRIC.equalsIgnoreCase(productType)
                ||  Constant.DictData.PRODUCT_TYPE_FLEXIBLE_ELECTRIC.equalsIgnoreCase(productType);
    }


    //产品订单发放平台信息
    private transient MerchantScmInformation scmGrantInfo;

    //产品订单 目标用户表
    private transient MerchantScmTargetUser scmGrantTargetUser;

    private transient MerchantScmProductInformation scmProductInfo;

    private transient MerchantScmOrderInformation orderInformation;

}
